import re

# template:
'''
    '': {
        'name': '',
        'symbol': '',
        'a_num': None,
        'a_mass': None,
        'a_radius': None,
        'electron_config': '', 
        'electronegativity': None,
        'electron_affinity': None,
        'ionization_energies': None,
        'class': '',
        'oxidation_nums': [],
        'melting_temp': None, 
        'boiling_temp': None,
        'd': None,
        'yr': 0 
    },
'''
class Element:
    __slots__ = (
        "name", "symbol", "a_num", "a_mass", "a_radius", "electron_config", 
        "electronegativity", "electron_affinity", "ionization_energies", 
        "e_class", "oxidation_nums", "melting_temp", "boiling_temp", "d", "yr",
        "_initialized"
    )
    
    def __init__(self, name, symbol, a_num, a_mass, a_radius, electron_config, 
                 electronegativity, electron_affinity, ionization_energies, e_class, 
                 oxidation_nums, melting_temp, boiling_temp, d, yr):
        self.name = name
        self.symbol = symbol
        self.a_num = a_num
        self.a_mass = a_mass
        self.a_radius = a_radius
        self.electron_config = electron_config
        self.electronegativity = electronegativity
        self.electron_affinity = electron_affinity
        self.ionization_energies = ionization_energies
        self.e_class = e_class
        self.oxidation_nums = oxidation_nums
        self.melting_temp = melting_temp
        self.boiling_temp = boiling_temp
        self.d = d
        self.yr = yr  
        self._initialized = True

    def __setattr__(self, key, value):
        if hasattr(self, '_initialized'):
            raise AttributeError("Element objects are immutable")
        super().__setattr__(key, value)
            
class Table:
    def __init__(self):
        data = {
            'H': {
                'name': 'Hydrogen',
                'symbol': 'H',
                'a_num': 1,
                'a_mass': 1.00794, # u
                'a_radius': 30, # pm (picometers)
                'electron_config': '1s1', 
                'electronegativity': 2.2,
                'electron_affinity': 72.8, # kJ/mol
                'ionization_energies': 1312, # kJ/mol
                'class': 'nonmetal',
                'oxidation_nums': [-1,1],
                'melting_temp': 14, # K
                'boiling_temp': 20, # K
                'd': 0.0899, # g/L
                'yr': 1766 # year of discovery
            },
            'He': {
                'name': 'Helium',
                'symbol': 'He',
                'a_num': 2,
                'a_mass': 4.003, # u
                'a_radius': 93, # pm (picometers)
                'electron_config': '1s2', 
                'electronegativity': None,
                'electron_affinity': None, # kJ/mol
                'ionization_energies': 2372, # kJ/mol
                'class': 'noble gas',
                'oxidation_nums': [],
                'melting_temp': 1, # K
                'boiling_temp': 4, # K
                'd': 0.18, # g/L
                'yr': 1895 # year of discovery
            },
            'Li': {
                'name': 'Lithium',
                'symbol': 'Li',
                'a_num': 3,
                'a_mass': 6.941, # u
                'a_radius': 155, # pm (picometers)
                'electron_config': '[He]2s1', 
                'electronegativity': 0.98,
                'electron_affinity': 59.6, # kJ/mol
                'ionization_energies': 513, # kJ/mol
                'class': 'alkali metal',
                'oxidation_nums': [1],
                'melting_temp': 454, # K
                'boiling_temp': 1615, # K
                'd': 530, # g/L
                'yr': 1817 # year of discovery
            },
            'Be': {
                'name': 'Beryllium',
                'symbol': 'Be',
                'a_num': 4,
                'a_mass': 9.012,
                'a_radius': 112,
                'electron_config': '[He]2s2', 
                'electronegativity': 1.57,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': 'alkali earth metal',
                'oxidation_nums': [2],
                'melting_temp': 1561, 
                'boiling_temp': 2744,
                'd': 1850,
                'yr': 1798 
            },
            'B': {
                'name': 'Boron',
                'symbol': 'B',
                'a_num': 5,
                'a_mass': 10.81,
                'a_radius': 98,
                'electron_config': '[He]2s22p1', 
                'electronegativity': 2.04,
                'electron_affinity': 26.7,
                'ionization_energies': 801,
                'class': 'semimetals',
                'oxidation_nums': [3],
                'melting_temp': 2573.15, 
                'boiling_temp': 3923.15,
                'd': 2470,
                'yr': 1808
            },
            'C': {
                'name': 'Carbon',
                'symbol': 'C',
                'a_num': 6,
                'a_mass': 12.01,
                'a_radius': 91,
                'electron_config': '[He]2s22p2', 
                'electronegativity': 2.55,
                'electron_affinity': 153.9,
                'ionization_energies': 1086,
                'class': 'nonmetal',
                'oxidation_nums': [-4, 2, 4],
                'melting_temp': None, 
                'boiling_temp': 3823.15,
                'd': 2260,
                'yr': 0 
            },
            'N': {
                'name': 'Nitrogen',
                'symbol': 'N',
                'a_num': 7,
                'a_mass': 14.01,
                'a_radius': 92,
                'electron_config': '[He]2s22p3', 
                'electronegativity': 3.04,
                'electron_affinity': 7,
                'ionization_energies': 1402,
                'class': 'nonmetal',
                'oxidation_nums': [-3, 2, 3, 4, 5],
                'melting_temp': 63, 
                'boiling_temp': 77,
                'd': 1.25,
                'yr': 1772
            },
            'O': {
                'name': 'Oxygen',
                'symbol': 'O',
                'a_num': 8,
                'a_mass': 16,
                'a_radius': 66,
                'electron_config': '[He]2s22p4', 
                'electronegativity': 3.44,
                'electron_affinity': 141,
                'ionization_energies': 1314,
                'class': 'nonmetal',
                'oxidation_nums': [-2],
                'melting_temp': 54, 
                'boiling_temp': 90,
                'd': 1.43,
                'yr': 1774
            },
            'F': {
                'name': 'Fluorine',
                'symbol': 'F',
                'a_num': 9,
                'a_mass': 19,
                'a_radius': 64,
                'electron_config': '[He]2s22p5', 
                'electronegativity': 3.98,
                'electron_affinity': 328,
                'ionization_energies': 1681,
                'class': 'halogens',
                'oxidation_nums': [-1],
                'melting_temp': 53, 
                'boiling_temp': 85,
                'd': 1.7,
                'yr': 1771
            },
            'Ne': {
                'name': 'Neon',
                'symbol': 'Ne',
                'a_num': 10,
                'a_mass': 20.18,
                'a_radius': 160,
                'electron_config': '[He]2s22p6', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': 2081,
                'class': 'noble gas',
                'oxidation_nums': [],
                'melting_temp': 24, 
                'boiling_temp': 27,
                'd': 0.9,
                'yr': 1898 
            },
            'Na': {
                'name': 'Sodium',
                'symbol': 'Na',
                'a_num': 11,
                'a_mass': 22.99,
                'a_radius': 190,
                'electron_config': '[Ne]3s1', 
                'electronegativity': 0.93,
                'electron_affinity': 52.8,
                'ionization_energies': 496,
                'class': 'alkali metals',
                'oxidation_nums': [1],
                'melting_temp': 371, 
                'boiling_temp': 1156,
                'd': 970,
                'yr': 1807
            },
            'Mg': {
                'name': 'Magnesium',
                'symbol': 'Mg',
                'a_num': 12,
                'a_mass': 24.31,
                'a_radius': 160,
                'electron_config': '[Ne]3s2', 
                'electronegativity': 1.31,
                'electron_affinity': None,
                'ionization_energies': 738,
                'class': 'alkali earth metal',
                'oxidation_nums': [2],
                'melting_temp': 923, 
                'boiling_temp': 1363,
                'd': 1740,
                'yr': 1755
            },
            'Al': {
                'name': 'Aluminum',
                'symbol': 'Al',
                'a_num': 13,
                'a_mass': 26.98,
                'a_radius': 143,
                'electron_config': '[Ne]3s23p1', 
                'electronegativity': 1.61,
                'electron_affinity': 42.5,
                'ionization_energies': 578,
                'class': 'p block transition metals',
                'oxidation_nums': [3],
                'melting_temp': 933, 
                'boiling_temp': 2792,
                'd': 2700,
                'yr': 1827
            },
            'Si': {
                'name': 'Silicon',
                'symbol': 'Si',
                'a_num': 14,
                'a_mass': 28.09,
                'a_radius': 132,
                'electron_config': '[Ne]3s23p2', 
                'electronegativity': 1.9,
                'electron_affinity': 133.6,
                'ionization_energies': 786,
                'class': 'semimetal',
                'oxidation_nums': [-4, 2, 4],
                'melting_temp': 1687, 
                'boiling_temp': 3553,
                'd': 2330,
                'yr': 1823 
            },
            'P': {
                'name': 'Phosphorus',
                'symbol': 'P',
                'a_num': 15,
                'a_mass': 30.97,
                'a_radius': 128,
                'electron_config': '[Ne]3s23p3', 
                'electronegativity': 2.19,
                'electron_affinity': 72,
                'ionization_energies': 1012,
                'class': 'nonmetal',
                'oxidation_nums': [-3, 3, 5],
                'melting_temp': 317, 
                'boiling_temp': 553,
                'd': 1820,
                'yr': 0
            },
            'S': {
                'name': 'Sulfur',
                'symbol': 'S',
                'a_num': 16,
                'a_mass': 32.07,
                'a_radius': 104,
                'electron_config': '[Ne]3s23p4', 
                'electronegativity': 2.58,
                'electron_affinity': 200,
                'ionization_energies': 1000,
                'class': 'nonmetal',
                'oxidation_nums': [-2, 4, 6],
                'melting_temp': 388, 
                'boiling_temp': 718,
                'd': 2090,
                'yr': 0 
            },
            'Cl': {
                'name': 'Chlorine',
                'symbol': 'Cl',
                'a_num': 17,
                'a_mass': 35.45,
                'a_radius': 99,
                'electron_config': '[Ne]3s23p5', 
                'electronegativity': 3.16,
                'electron_affinity': 349,
                'ionization_energies': 1251,
                'class': 'halogens',
                'oxidation_nums': [-1, 1, 3, 5, 7],
                'melting_temp': 172, 
                'boiling_temp': 238,
                'd': 3.21,
                'yr': 1774 
            },
            'Ar': {
                'name': 'Argon',
                'symbol': 'Ar',
                'a_num': 18,
                'a_mass': 39.95,
                'a_radius': 191,
                'electron_config': '[Ne]3s23p6', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': 1521,
                'class': 'noble gas',
                'oxidation_nums': [],
                'melting_temp': 84, 
                'boiling_temp': 87,
                'd': 1.78,
                'yr': 1894
            },
            'K': {
                'name': 'Potassium',
                'symbol': 'K',
                'a_num': 19,
                'a_mass': 39.1,
                'a_radius': 235,
                'electron_config': '[Ar]4s1', 
                'electronegativity': 0.82,
                'electron_affinity': 48.4,
                'ionization_energies': 419,
                'class': 'alkali metal',
                'oxidation_nums': [1],
                'melting_temp': 336, 
                'boiling_temp': 1033,
                'd': 860,
                'yr': 1807 
            },
            'Ca': {
                'name': 'Calcium',
                'symbol': 'Ca',
                'a_num': 20,
                'a_mass': 40.08,
                'a_radius': 197,
                'electron_config': '[Ar]4s2', 
                'electronegativity': 1,
                'electron_affinity': 2.37,
                'ionization_energies': 590,
                'class': 'alkaline earth metal',
                'oxidation_nums': [2],
                'melting_temp': 1115, 
                'boiling_temp': 1757,
                'd': 1530,
                'yr': 1808
            },
            'Sc': {
                'name': 'Scandium',
                'symbol': 'Sc',
                'a_num': 21,
                'a_mass': 44.96,
                'a_radius': 160,
                'electron_config': '[Ar]3d14s2', 
                'electronegativity': 1.36,
                'electron_affinity': 18.1,
                'ionization_energies': 631,
                'class': 'd block transition metal',
                'oxidation_nums': [3],
                'melting_temp': 1814, 
                'boiling_temp': 3109,
                'd': 2990,
                'yr': 1879 
            },
            'Ti': {
                'name': 'Titanium',
                'symbol': 'Ti',
                'a_num': 22,
                'a_mass': 47.87,
                'a_radius': 146,
                'electron_config': '[Ar]3d24s2', 
                'electronegativity': 1.54,
                'electron_affinity': 7.6,
                'ionization_energies': 658,
                'class': 'd block transition metal',
                'oxidation_nums': [2, 3, 4],
                'melting_temp': 1941, 
                'boiling_temp': 3560,
                'd': 4550,
                'yr': 1791
            },
            'V': {
                'name': 'Vanadium',
                'symbol': 'V',
                'a_num': 23,
                'a_mass': 50.94,
                'a_radius': 134,
                'electron_config': '[Ar]3d34s2', 
                'electronegativity': 1.63,
                'electron_affinity': 50.6,
                'ionization_energies': 651,
                'class': 'd block transition metal',
                'oxidation_nums': [2, 3, 4, 5],
                'melting_temp': 2183, 
                'boiling_temp': 3680,
                'd': 6110,
                'yr': 1830 
            },
            'Cr': {
                'name': 'Chromium',
                'symbol': 'Cr',
                'a_num': 24,
                'a_mass': 52,
                'a_radius': 127,
                'electron_config': '[Ar]3d54s1', 
                'electronegativity': 1.66,
                'electron_affinity': 64.3,
                'ionization_energies': 653,
                'class': 'd block transition metal',
                'oxidation_nums': [2, 3, 6],
                'melting_temp': 2180, 
                'boiling_temp': 2945,
                'd': 7190,
                'yr': 1797 
            },
            'Mn': {
                'name': 'Manganese',
                'symbol': 'Mn',
                'a_num': 25,
                'a_mass': 54.94,
                'a_radius': 126,
                'electron_config': '[Ar]3d54s2', 
                'electronegativity': 1.55,
                'electron_affinity': None,
                'ionization_energies': 717,
                'class': 'd block transition metal',
                'oxidation_nums': [2, 3, 4, 6, 7],
                'melting_temp': 1517, 
                'boiling_temp': 2334,
                'd': 7430,
                'yr': 1774
            },
            'Fe': {
                'name': 'Iron',
                'symbol': 'Fe',
                'a_num': 26,
                'a_mass': 55.85,
                'a_radius': 126,
                'electron_config': '[Ar]3d64s2', 
                'electronegativity': 1.83,
                'electron_affinity': 15.7,
                'ionization_energies': 759,
                'class': 'd block transition metal',
                'oxidation_nums': [2, 3],
                'melting_temp': 1808, 
                'boiling_temp': 3134,
                'd': 7860,
                'yr': 0 
            },
            'Co': {
                'name': 'Cobalt',
                'symbol': 'Co',
                'a_num': 27,
                'a_mass': 58.93,
                'a_radius': 125,
                'electron_config': '[Ar]3d74s2', 
                'electronegativity': 1.88,
                'electron_affinity': 63.7,
                'ionization_energies': 758,
                'class': 'd block transition metal',
                'oxidation_nums': [2, 3],
                'melting_temp': 1768, 
                'boiling_temp': 3200,
                'd': 8800,
                'yr': 1735
            },
            'Ni': {
                'name': 'Nickel',
                'symbol': 'Ni',
                'a_num': 28,
                'a_mass': 58.69,
                'a_radius': 124,
                'electron_config': '[Ar]3d84s2', 
                'electronegativity': 1.91,
                'electron_affinity': 112,
                'ionization_energies': 737,
                'class': 'd block tranisition metal',
                'oxidation_nums': [2, 3],
                'melting_temp': 1728, 
                'boiling_temp': 3186,
                'd': 8900,
                'yr': 1751 
            },
            'Cu': {
                'name': 'Copper',
                'symbol': 'Cu',
                'a_num': 29,
                'a_mass': 63.55,
                'a_radius': 128,
                'electron_config': '[Ar]3d104s1', 
                'electronegativity': 1.9,
                'electron_affinity': 118.4,
                'ionization_energies': 745,
                'class': 'd block transition metal',
                'oxidation_nums': [1, 2],
                'melting_temp': 1357, 
                'boiling_temp': 2840,
                'd': 8960,
                'yr': 0
            },
            'Zn': {
                'name': 'Zinc',
                'symbol': 'Zn',
                'a_num': 30,
                'a_mass': 65.38,
                'a_radius': 133,
                'electron_config': '[Ar]3d104s2', 
                'electronegativity': 1.65,
                'electron_affinity': None,
                'ionization_energies': 906,
                'class': 'd block transition metal',
                'oxidation_nums': [2],
                'melting_temp': 693, 
                'boiling_temp': 1180,
                'd': 7140,
                'yr': 1746
            },
            'Ga': {
                'name': 'Gallium',
                'symbol': 'Ga',
                'a_num': 31,
                'a_mass': 69.72,
                'a_radius': 141,
                'electron_config': '[Ar]3d104s24p1', 
                'electronegativity': 1.81,
                'electron_affinity': 28.9,
                'ionization_energies': 579,
                'class': 'p block transition metals',
                'oxidation_nums': [3],
                'melting_temp': 303, 
                'boiling_temp': 2477,
                'd': 5910,
                'yr': 1875 
            },
            'Ge': {
                'name': 'Germanium',
                'symbol': 'Ge',
                'a_num': 32,
                'a_mass': 72.63,
                'a_radius': 137,
                'electron_config': '[Ar]3d104s24p2', 
                'electronegativity': 2.01,
                'electron_affinity': 119,
                'ionization_energies': 762,
                'class': 'semimetal',
                'oxidation_nums': [2, 4],
                'melting_temp': 1210, 
                'boiling_temp': 3103,
                'd': 5320,
                'yr': 1886 
            },
            'As': {
                'name': 'Arsenic',
                'symbol': 'As',
                'a_num': 33,
                'a_mass': 74.92,
                'a_radius': 139,
                'electron_config': '[Ar]3d104s24p3', 
                'electronegativity': 2.18,
                'electron_affinity': 78,
                'ionization_energies': 947,
                'class': 'semimetal',
                'oxidation_nums': [-3, 3, 5],
                'melting_temp': 1090.15, 
                'boiling_temp': None,
                'd': 5730,
                'yr': 0 
            },
            'Se': {
                'name': 'Selenium',
                'symbol': 'Se',
                'a_num': 34,
                'a_mass': 78.96,
                'a_radius': 140,
                'electron_config': '[Ar]3d104s24p4', 
                'electronegativity': 2.55,
                'electron_affinity': 195,
                'ionization_energies': 941,
                'class': 'nonmetal',
                'oxidation_nums': [-2, 4, 6],
                'melting_temp': 494, 
                'boiling_temp': 958,
                'd': 4810,
                'yr': 1817 
            },
            'Br': {
                'name': 'Bromine',
                'symbol': 'Br',
                'a_num': 35,
                'a_mass': 79.9,
                'a_radius': 114,
                'electron_config': '[Ar]3d104s24p5', 
                'electronegativity': 2.96,
                'electron_affinity': 324.6,
                'ionization_energies': 1140,
                'class': 'halogens',
                'oxidation_nums': [-1, 1, 3, 5],
                'melting_temp': 266, 
                'boiling_temp': 332,
                'd': 3120,
                'yr': 1826 
            },
            'Kr': {
                'name': 'Krypton',
                'symbol': 'Kr',
                'a_num': 36,
                'a_mass': 83.8,
                'a_radius': 200,
                'electron_config': '[Ar]3d104s24p6', 
                'electronegativity': 3,
                'electron_affinity': None,
                'ionization_energies': 1351,
                'class': 'noble gas',
                'oxidation_nums': [],
                'melting_temp': 116, 
                'boiling_temp': 121,
                'd': 3.75,
                'yr': 1897 
            },
            'Rb': {
                'name': 'Rubidium',
                'symbol': 'Rb',
                'a_num': 37,
                'a_mass': 85.47,
                'a_radius': 248,
                'electron_config': '[Kr]5s1', 
                'electronegativity': 0.82,
                'electron_affinity': 46.9,
                'ionization_energies': 403,
                'class': 'alkali metal',
                'oxidation_nums': [1],
                'melting_temp': 312, 
                'boiling_temp': 959,
                'd': 1530,
                'yr': 1861 
            },
            'Sr': {
                'name': 'Strontium',
                'symbol': 'Sr',
                'a_num': 38,
                'a_mass': 87.62,
                'a_radius': 215,
                'electron_config': '[Kr]5s2', 
                'electronegativity': 0.95,
                'electron_affinity': 5.03,
                'ionization_energies': 549,
                'class': '[Kr]5s2',
                'oxidation_nums': [2],
                'melting_temp': 1050, 
                'boiling_temp': 1657,
                'd': 2600,
                'yr': 1790 
            },
            'Y': {
                'name': 'Yttrio',
                'symbol': 'Y',
                'a_num': 39,
                'a_mass': 88.91,
                'a_radius': 179,
                'electron_config': '[Kr]4d15s2', 
                'electronegativity': 1.22,
                'electron_affinity': 29.6,
                'ionization_energies': 616,
                'class': 'd block transition metal',
                'oxidation_nums': [3],
                'melting_temp': 1796, 
                'boiling_temp': 3618,
                'd': 4470,
                'yr': 1794 
            },
            'Zr': {
                'name': 'Zirconium',
                'symbol': 'Zr',
                'a_num': 40,
                'a_mass': 91.22,
                'a_radius': 160,
                'electron_config': '[Kr]4d25s2', 
                'electronegativity': 1.33,
                'electron_affinity': 41.1,
                'ionization_energies': 660,
                'class': 'd block tranistion metal',
                'oxidation_nums': [4],
                'melting_temp': 2125, 
                'boiling_temp': 4682,
                'd': 6490,
                'yr': 1789 
            },
            'Nb': {
                'name': 'Niobium',
                'symbol': 'Nb',
                'a_num': 41,
                'a_mass': 92.91,
                'a_radius': 146,
                'electron_config': '[Kr]4d45s1', 
                'electronegativity': 1.6,
                'electron_affinity': 86.1,
                'ionization_energies': 664,
                'class': 'd block transition metal',
                'oxidation_nums': [3, 5],
                'melting_temp': 2741, 
                'boiling_temp': 5015,
                'd': 8570,
                'yr': 1801 
            },
            'Mo': {
                'name': 'Molybdenum',
                'symbol': 'Mo',
                'a_num': 42,
                'a_mass': 95.95,
                'a_radius': 139,
                'electron_config': '[Kr]4d55s1', 
                'electronegativity': 2.16,
                'electron_affinity': 71.9,
                'ionization_energies': 685,
                'class': 'd block transition metal',
                'oxidation_nums': [1, 2, 3, 4, 5, 6],
                'melting_temp': 2829, 
                'boiling_temp': 4912,
                'd': 10200,
                'yr': 1778 
            },
            'Tc': {
                'name': 'Technetium',
                'symbol': 'Tc',
                'a_num': 43,
                'a_mass': 98.91,
                'a_radius': 136,
                'electron_config': '[Kr]4d55s2', 
                'electronegativity': 1.9,
                'electron_affinity': 53,
                'ionization_energies': 702,
                'class': 'd block transition metal',
                'oxidation_nums': [4, 5, 6, 7],
                'melting_temp': 2430, 
                'boiling_temp': 4538,
                'd': 11500,
                'yr': 1937 
            },
            'Ru': {
                'name': 'Ruthenium',
                'symbol': 'Ru',
                'a_num': 44,
                'a_mass': 101.1,
                'a_radius': 133,
                'electron_config': '[Kr]4d75s1', 
                'electronegativity': 2.2,
                'electron_affinity': 101.3,
                'ionization_energies': 711,
                'class': 'd block transition metal',
                'oxidation_nums': [2, 3, 4, 5, 6, 7],
                'melting_temp': 2607, 
                'boiling_temp': 4423,
                'd': 12500,
                'yr': 1844 
            },
            'Rh': {
                'name': 'Rhodium',
                'symbol': 'Rh',
                'a_num': 45,
                'a_mass': 102.9,
                'a_radius': 134,
                'electron_config': '[Kr]4d85s1', 
                'electronegativity': 2.28,
                'electron_affinity': 109.7,
                'ionization_energies': 720,
                'class': 'd block transition metal',
                'oxidation_nums': [3],
                'melting_temp': 2239, 
                'boiling_temp': 3968,
                'd': 12400,
                'yr': 1803 
            },
            'Pd': {
                'name': 'Palladium',
                'symbol': 'Pd',
                'a_num': 46,
                'a_mass': 106.4,
                'a_radius': 138,
                'electron_config': '[Kr]4d10', 
                'electronegativity': 2.2,
                'electron_affinity': 53.7,
                'ionization_energies': 805,
                'class': 'd block transition metal',
                'oxidation_nums': [2, 4],
                'melting_temp': 1826, 
                'boiling_temp': 3236,
                'd': 12000,
                'yr': 1803 
            },
            'Ag': {
                'name': 'Silver',
                'symbol': 'Ag',
                'a_num': 47,
                'a_mass': 107.9,
                'a_radius': 144,
                'electron_config': '[Kr]4d105s1', 
                'electronegativity': 1.93,
                'electron_affinity': 125.6,
                'ionization_energies': 731,
                'class': 'd block transition metal',
                'oxidation_nums': [1],
                'melting_temp': 1235, 
                'boiling_temp': 2435,
                'd': 10500,
                'yr': 0 
            },
            'Cd': {
                'name': 'Cadmium',
                'symbol': 'Cd',
                'a_num': 48,
                'a_mass': 112.4,
                'a_radius': 154,
                'electron_config': '[Kr]4d105s2', 
                'electronegativity': 1.69,
                'electron_affinity': None,
                'ionization_energies': 868,
                'class': 'd block transition metal',
                'oxidation_nums': [2],
                'melting_temp': 594, 
                'boiling_temp': 1038,
                'd': 8650,
                'yr': 1817 
            },
            'In': {
                'name': 'Indium',
                'symbol': 'In',
                'a_num': 49,
                'a_mass': 114.8,
                'a_radius': 166,
                'electron_config': '[Kr]4d105s25p1', 
                'electronegativity': 1.78,
                'electron_affinity': 28.9,
                'ionization_energies': 558,
                'class': 'p block transition metal',
                'oxidation_nums': [3],
                'melting_temp': 430, 
                'boiling_temp': 2345,
                'd': 7310,
                'yr': 1863 
            },
            'Sn': {
                'name': 'Tin',
                'symbol': 'Sn',
                'a_num': 50,
                'a_mass': 118.7,
                'a_radius': 162,
                'electron_config': '[Kr]4d105s25p2', 
                'electronegativity': 1.96,
                'electron_affinity': 107.3,
                'ionization_energies': 709,
                'class': 'p block transition metal',
                'oxidation_nums': [2, 4],
                'melting_temp': 505, 
                'boiling_temp': 2875,
                'd': 7290,
                'yr': 0 
            },
            'Sb': {
                'name': 'Antimony',
                'symbol': 'Sb',
                'a_num': 51,
                'a_mass': 121.8,
                'a_radius': 159,
                'electron_config': '[Kr]4d105s25p3', 
                'electronegativity': 2.05,
                'electron_affinity': 103.2,
                'ionization_energies': 834,
                'class': 'semimetal',
                'oxidation_nums': [-3, 3, 5],
                'melting_temp': 904, 
                'boiling_temp': 1860,
                'd': 6680,
                'yr': 0 
            },
            'Te': {
                'name': 'Tellurium',
                'symbol': 'Te',
                'a_num': 52,
                'a_mass': 127.6,
                'a_radius': 160,
                'electron_config': '[Kr]4d105s25p4', 
                'electronegativity': 2.1,
                'electron_affinity': 190.2,
                'ionization_energies': 869,
                'class': 'semimetal',
                'oxidation_nums': [-2, 4, 6],
                'melting_temp': 723, 
                'boiling_temp': 1261,
                'd': 6240,
                'yr': 1782 
            },
            'I': {
                'name': 'Iodine',
                'symbol': 'I',
                'a_num': 53,
                'a_mass': 126.9,
                'a_radius': 133,
                'electron_config': '[Kr]4d105s25p5', 
                'electronegativity': 2.66,
                'electron_affinity': 295.2,
                'ionization_energies': 1008,
                'class': 'halogens',
                'oxidation_nums': [-1, 1, 3, 5, 7],
                'melting_temp': 387, 
                'boiling_temp': 457,
                'd': 4930,
                'yr': 1811 
            },
            'Xe': {
                'name': 'Xenon',
                'symbol': 'Xe',
                'a_num': 54,
                'a_mass': 131.3,
                'a_radius': 220,
                'electron_config': '[Kr]4d105s25p6', 
                'electronegativity': 2.6,
                'electron_affinity': None,
                'ionization_energies': 1170,
                'class': 'noble gas',
                'oxidation_nums': [],
                'melting_temp': 161, 
                'boiling_temp': 166,
                'd': 5.9,
                'yr': 1898 
            },
            'Cs': {
                'name': 'Cesium',
                'symbol': 'Cs',
                'a_num': 55,
                'a_mass': 132.9,
                'a_radius': 267,
                'electron_config': '[Xe]6s1', 
                'electronegativity': 0.79,
                'electron_affinity': 45.5,
                'ionization_energies': 376,
                'class': 'alkali metal',
                'oxidation_nums': [1],
                'melting_temp': 301, 
                'boiling_temp': 942,
                'd': 1870,
                'yr': 1860 
            },
            'Ba': {
                'name': 'Barium',
                'symbol': 'Ba',
                'a_num': 56,
                'a_mass': 137.3,
                'a_radius': 222,
                'electron_config': '[Xe]6s2', 
                'electronegativity': 0.89,
                'electron_affinity': 13.95,
                'ionization_energies': 503,
                'class': 'alkaline earth metal',
                'oxidation_nums': [2],
                'melting_temp': 1000, 
                'boiling_temp': 2170,
                'd': 2590,
                'yr': 1808 
            },
            'La': {
                'name': 'Lanthanum',
                'symbol': 'La',
                'a_num': 57,
                'a_mass': 138.9,
                'a_radius': 187,
                'electron_config': '[Xe]6s25d1', 
                'electronegativity': 1.1,
                'electron_affinity': 48,
                'ionization_energies': 538,
                'class': 'lanthanide',
                'oxidation_nums': [3],
                'melting_temp': 1193, 
                'boiling_temp': 3727,
                'd': 6170,
                'yr': 1839 
            },
            'Ce': {
                'name': 'Cerium',
                'symbol': 'Ce',
                'a_num': 58,
                'a_mass': 140.1,
                'a_radius': 183,
                'electron_config': '[Xe]4f15d16s2', 
                'electronegativity': 1.12,
                'electron_affinity': 50,
                'ionization_energies': 534,
                'class': 'lanthanide',
                'oxidation_nums': [3, 4],
                'melting_temp': 1068, 
                'boiling_temp': 3697,
                'd': 6770,
                'yr': 1803
            },
            'Pr': {
                'name': 'Praseodymium',
                'symbol': 'Pr',
                'a_num': 59,
                'a_mass': 140.9,
                'a_radius': 182,
                'electron_config': '[Xe]4f36s2', 
                'electronegativity': 1.13,
                'electron_affinity': 50,
                'ionization_energies': 540,
                'class': 'lanthanide',
                'oxidation_nums': [3],
                'melting_temp': 1204, 
                'boiling_temp': 3793,
                'd': 6770,
                'yr': 1885 
            },
            'Nd': {
                'name': 'Neodymium',
                'symbol': 'Nd',
                'a_num': 60,
                'a_mass': 144.2,
                'a_radius': 180,
                'electron_config': '[Xe]4f46s2', 
                'electronegativity': 1.14,
                'electron_affinity': 50,
                'ionization_energies': 533,
                'class': 'lanthanide',
                'oxidation_nums': [3],
                'melting_temp': 1297, 
                'boiling_temp': 3347,
                'd': 7200,
                'yr': 1885 
            },
            'Pm': {
                'name': 'Promethium',
                'symbol': 'Pm',
                'a_num': 61,
                'a_mass': 145,
                'a_radius': None,
                'electron_config': '[Xe]4f56s2', 
                'electronegativity': None,
                'electron_affinity': 50,
                'ionization_energies': 540,
                'class': 'lanthanide',
                'oxidation_nums': [3],
                'melting_temp': 1315, 
                'boiling_temp': 3273,
                'd': 7400,
                'yr': 1945 
            },
            'Sm': {
                'name': 'Samarium',
                'symbol': 'Sm',
                'a_num': 62,
                'a_mass': 150.4,
                'a_radius': 177,
                'electron_config': '[Xe]4f66s2', 
                'electronegativity': 1.17,
                'electron_affinity': 50,
                'ionization_energies': 545,
                'class': 'lanthanide',
                'oxidation_nums': [2, 3],
                'melting_temp': 1072, 
                'boiling_temp': 1794,
                'd': 8100,
                'yr': 1879 
            },
            'Eu': {
                'name': 'Europium',
                'symbol': 'Eu',
                'a_num': 63,
                'a_mass': 151.2,
                'a_radius': 175,
                'electron_config': '[Xe]4f76s2', 
                'electronegativity': 1.2,
                'electron_affinity': 50,
                'ionization_energies': 547,
                'class': 'lanthanide',
                'oxidation_nums': [2, 3],
                'melting_temp': 1095, 
                'boiling_temp': 1802,
                'd': 5240,
                'yr': 1896 
            },
            'Gd': {
                'name': 'Gadolinium',
                'symbol': 'Gd',
                'a_num': 64,
                'a_mass': 157.3,
                'a_radius': 173,
                'electron_config': '[Xe]4f75d16s2', 
                'electronegativity': 1.2,
                'electron_affinity': 50,
                'ionization_energies': 593,
                'class': 'lanthanide',
                'oxidation_nums': [3],
                'melting_temp': 1311, 
                'boiling_temp': 3273,
                'd': 7890,
                'yr': 1880 
            },
            'Tb': {
                'name': 'Terbium',
                'symbol': 'Tb',
                'a_num': 65,
                'a_mass': 158.9,
                'a_radius': 172,
                'electron_config': '[Xe]4f96s2', 
                'electronegativity': 1.2,
                'electron_affinity': 50,
                'ionization_energies': 565,
                'class': 'lanthanide',
                'oxidation_nums': [3],
                'melting_temp': 1356, 
                'boiling_temp': 1629,
                'd': 8270,
                'yr': 1843 
            },
            'Dy': {
                'name': 'Dysprosium',
                'symbol': 'Dy',
                'a_num': 66,
                'a_mass': 162.5,
                'a_radius': 171,
                'electron_config': '[Xe]4f106s2', 
                'electronegativity': 1.22,
                'electron_affinity': 50,
                'ionization_energies': 573,
                'class': 'lanthanide',
                'oxidation_nums': [3],
                'melting_temp': 1412, 
                'boiling_temp': 2562,
                'd': 8530,
                'yr': 1886 
            },
            'Ho': {
                'name': 'Holmium',
                'symbol': 'Ho',
                'a_num': 67,
                'a_mass': 164.9,
                'a_radius': 176,
                'electron_config': '[Xe]4f116s2', 
                'electronegativity': 1.23,
                'electron_affinity': 50,
                'ionization_energies': 581,
                'class': 'lanthanide',
                'oxidation_nums': [3],
                'melting_temp': 1743, 
                'boiling_temp': 2993,
                'd': 8800,
                'yr': 1879
            },
            'Er': {
                'name': 'Erbium',
                'symbol': 'Er',
                'a_num': 68,
                'a_mass': 167.3,
                'a_radius': 167,
                'electron_config': '[Xe]4f126s2', 
                'electronegativity': 1.24,
                'electron_affinity': 50,
                'ionization_energies': 588,
                'class': 'lanthanide',
                'oxidation_nums': [3],
                'melting_temp': 1795, 
                'boiling_temp': 3141,
                'd': 9050,
                'yr': 1843 
            },
            'Tm': {
                'name': 'Thulium',
                'symbol': 'Tm',
                'a_num': 69,
                'a_mass': 168.9,
                'a_radius': 166,
                'electron_config': '[Xe]4f136s2', 
                'electronegativity': 1.25,
                'electron_affinity': 50,
                'ionization_energies': 596,
                'class': 'lanthanide',
                'oxidation_nums': [2, 3],
                'melting_temp': 1818, 
                'boiling_temp': 2223,
                'd': 9330,
                'yr': 1879 
            },
            'Yb': {
                'name': 'Ytterbium',
                'symbol': 'Yb',
                'a_num': 70,
                'a_mass': 173,
                'a_radius': 192,
                'electron_config': '[Xe]4f146s2', 
                'electronegativity': 1.1,
                'electron_affinity': 50,
                'ionization_energies': 603,
                'class': 'lanthanide',
                'oxidation_nums': [2, 3],
                'melting_temp': 1878, 
                'boiling_temp': 1700,
                'd': 6980,
                'yr': 1907 
            },
            'Lu': {
                'name': 'Lutetium',
                'symbol': 'Lu',
                'a_num': 71,
                'a_mass': 174.9,
                'a_radius': 164,
                'electron_config': '[Xe]4f145d16s2', 
                'electronegativity': 1.27,
                'electron_affinity': 50,
                'ionization_energies': 524,
                'class': 'lanthanide',
                'oxidation_nums': [3],
                'melting_temp': 1929, 
                'boiling_temp': 3588,
                'd': 9840,
                'yr': 1907 
            },
            'Hf': {
                'name': 'Hafnium',
                'symbol': 'Hf',
                'a_num': 72,
                'a_mass': 178.5,
                'a_radius': 156,
                'electron_config': '[Xe]4f145d26s2', 
                'electronegativity': 1.3,
                'electron_affinity': 31.8,
                'ionization_energies': 658,
                'class': 'd block transition metal',
                'oxidation_nums': [4],
                'melting_temp': 2506, 
                'boiling_temp': 4875,
                'd': 13300,
                'yr': 1923 
            },
            'Ta': {
                'name': 'Tantalum',
                'symbol': 'Ta',
                'a_num': 73,
                'a_mass': 180.9,
                'a_radius': 146,
                'electron_config': '[Xe]4f145d36s2', 
                'electronegativity': 1.5,
                'electron_affinity': 31,
                'ionization_energies': 761,
                'class': 'd block transition metal',
                'oxidation_nums': [5],
                'melting_temp': 3290, 
                'boiling_temp': 5458,
                'd': 16600,
                'yr': 1802 
            },
            'W': {
                'name': 'Tungsten',
                'symbol': 'W',
                'a_num': 74,
                'a_mass': 183.8,
                'a_radius': 139,
                'electron_config': '[Xe]4f145d46s2', 
                'electronegativity': 2.36,
                'electron_affinity': 78.2,
                'ionization_energies': 770,
                'class': 'd block transition metal',
                'oxidation_nums': [2, 3, 4, 5, 6],
                'melting_temp': 3422, 
                'boiling_temp': 5555,
                'd': 19300,
                'yr': 1781 
            },
            'Re': {
                'name': 'Rhenium',
                'symbol': 'Re',
                'a_num': 75,
                'a_mass': 186.2,
                'a_radius': 137,
                'electron_config': '[Xe]4f145d56s2', 
                'electronegativity': 1.9,
                'electron_affinity': 76,
                'ionization_energies': 760,
                'class': 'd block transition metal',
                'oxidation_nums': [4, 6, 7],
                'melting_temp': 3186, 
                'boiling_temp': 5869,
                'd': 21000,
                'yr': 1925 
            },
            'Os': {
                'name': 'Osmium',
                'symbol': 'Os',
                'a_num': 76,
                'a_mass': 190.2,
                'a_radius': 133,
                'electron_config': '[Xe]4f145d66s2', 
                'electronegativity': 2.2,
                'electron_affinity': 106.1,
                'ionization_energies': 839,
                'class': 'd block transition metal',
                'oxidation_nums': [2, 3, 4, 6, 8],
                'melting_temp': 3306, 
                'boiling_temp': 5285,
                'd': 22600,
                'yr': 1803 
            },
            'Ir': {
                'name': 'Iridium',
                'symbol': 'Ir',
                'a_num': 77,
                'a_mass': 192.2,
                'a_radius': 132,
                'electron_config': '[Xe]4f145d76s2', 
                'electronegativity': 2.2,
                'electron_affinity': 151.2,
                'ionization_energies': 880,
                'class': 'd block transition metal',
                'oxidation_nums': [3, 4],
                'melting_temp': 2719, 
                'boiling_temp': 4701,
                'd': 22500,
                'yr': 1803 
            },
            'Pt': {
                'name': 'Platinum',
                'symbol': 'Pt',
                'a_num': 78,
                'a_mass': 195.1,
                'a_radius': 139,
                'electron_config': '[Xe]4f145d96s1', 
                'electronegativity': 2.28,
                'electron_affinity': 205.3,
                'ionization_energies': 868,
                'class': 'd block transition metal',
                'oxidation_nums': [2, 4],
                'melting_temp': 2041, 
                'boiling_temp': 4100,
                'd': 21400,
                'yr': 1735 
            },
            'Au': {
                'name': 'Gold',
                'symbol': 'Au',
                'a_num': 79,
                'a_mass': 197,
                'a_radius': 144,
                'electron_config': '[Xe]4f145d106s1', 
                'electronegativity': 2.54,
                'electron_affinity': 222.3,
                'ionization_energies': 890,
                'class': 'd block transition metal',
                'oxidation_nums': [1, 3],
                'melting_temp': 1337, 
                'boiling_temp': 3129,
                'd': 19300,
                'yr': 0 
            },
            'Hg': {
                'name': 'Mercury',
                'symbol': 'Hg',
                'a_num': 80,
                'a_mass': 200.6,
                'a_radius': 155,
                'electron_config': '[Xe]4f145d106s2', 
                'electronegativity': 2,
                'electron_affinity': None,
                'ionization_energies': 1007,
                'class': 'd block transition metal',
                'oxidation_nums': [1, 2],
                'melting_temp': 234, 
                'boiling_temp': 629,
                'd': 13500,
                'yr': 0 
            },
            'Tl': {
                'name': 'Thallium',
                'symbol': 'Tl',
                'a_num': 81,
                'a_mass': 204.4,
                'a_radius': 156,
                'electron_config': '[Xe]4f145d106s26p1', 
                'electronegativity': 1.62,
                'electron_affinity': 24.2,
                'ionization_energies': 589,
                'class': 'p block transition metal',
                'oxidation_nums': [1, 3],
                'melting_temp': 577, 
                'boiling_temp': 1457,
                'd': 10000,
                'yr': 1861 
            },
            'Pb': {
                'name': 'Lead',
                'symbol': 'Pb',
                'a_num': 82,
                'a_mass': 207.2,
                'a_radius': 175,
                'electron_config': '[Xe]4f145d106s26p2', 
                'electronegativity': 1.87,
                'electron_affinity': 35.1,
                'ionization_energies': 715,
                'class': 'p block transition metal',
                'oxidation_nums': [2, 4],
                'melting_temp': 601, 
                'boiling_temp': 2013,
                'd': 11400,
                'yr': 0 
            },
            'Bi': {
                'name': 'Bismuth',
                'symbol': 'Bi',
                'a_num': 83,
                'a_mass': 208.9,
                'a_radius': 156,
                'electron_config': '[Xe]4f145d106s26p3', 
                'electronegativity': 2.02,
                'electron_affinity': 90.6,
                'ionization_energies': 703,
                'class': 'semimetal',
                'oxidation_nums': [-3, 3, 5],
                'melting_temp': 544, 
                'boiling_temp': 1564,
                'd': 9800,
                'yr': 1739
            },
            'Po': {
                'name': 'Polonium',
                'symbol': 'Po',
                'a_num': 84,
                'a_mass': 209,
                'a_radius': 140,
                'electron_config': '[Xe]4f145d106s26p4', 
                'electronegativity': 2,
                'electron_affinity': 183.3,
                'ionization_energies': 812,
                'class': 'semimetal',
                'oxidation_nums': [2, 4],
                'melting_temp': 254, 
                'boiling_temp': 962,
                'd': 9200,
                'yr': 1898 
            },
            'At': {
                'name': 'Astatine',
                'symbol': 'At',
                'a_num': 85,
                'a_mass': 210,
                'a_radius': 202,
                'electron_config': '[Xe]4f145d106s26p5', 
                'electronegativity': 2.2,
                'electron_affinity': None,
                'ionization_energies': 920,
                'class': 'halogens',
                'oxidation_nums': [-1, 1, 3, 5, 7],
                'melting_temp': 575, 
                'boiling_temp': 610,
                'd': 9320,
                'yr': 1940 
            },
            'Rn': {
                'name': 'Radon',
                'symbol': 'Rn',
                'a_num': 86,
                'a_mass': 222,
                'a_radius': 216,
                'electron_config': '[Xe]4f145d106s26p6', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': 1037,
                'class': 'noble gas',
                'oxidation_nums': [],
                'melting_temp': 202, 
                'boiling_temp': 211,
                'd': 9.72,
                'yr': 1900 
            },
            'Fr': {
                'name': 'Francium',
                'symbol': 'Fr',
                'a_num': 87,
                'a_mass': 223,
                'a_radius': 272,
                'electron_config': '[Rn]7s1', 
                'electronegativity': 0.7,
                'electron_affinity': None,
                'ionization_energies': 380,
                'class': 'alkali metal',
                'oxidation_nums': [1],
                'melting_temp': 300, 
                'boiling_temp': 950,
                'd': 1000,
                'yr': 1939 
            },
            'Ra': {
                'name': 'Radium',
                'symbol': 'Ra',
                'a_num': 88,
                'a_mass': 226,
                'a_radius': 222,
                'electron_config': '[Rn]7s2', 
                'electronegativity': 0.9,
                'electron_affinity': None,
                'ionization_energies': 509,
                'class': 'alkaline earth metal',
                'oxidation_nums': [2],
                'melting_temp': 973, 
                'boiling_temp': 1413,
                'd': 5000,
                'yr': 1898 
            },
            'Ac': {
                'name': 'Actinium',
                'symbol': 'Ac',
                'a_num': 89,
                'a_mass': 227,
                'a_radius': 180,
                'electron_config': '[Rn]7s25f1', 
                'electronegativity': 1.1,
                'electron_affinity': None,
                'ionization_energies': 499,
                'class': 'actinide',
                'oxidation_nums': [3],
                'melting_temp': 1050, 
                'boiling_temp': 1500,
                'd': 10100,
                'yr': 1899 
            },
            'Th': {
                'name': 'Thorium',
                'symbol': 'Th',
                'a_num': 90,
                'a_mass': 232,
                'a_radius': None,
                'electron_config': '[Rn]6d27s2', 
                'electronegativity': 1.3,
                'electron_affinity': None,
                'ionization_energies': 587,
                'class': 'actinide',
                'oxidation_nums': [4],
                'melting_temp': 2023, 
                'boiling_temp': 5061,
                'd': 11700,
                'yr': 1828 
            },
            'Pa': {
                'name': 'Protactinium',
                'symbol': 'Pa',
                'a_num': 91,
                'a_mass': 231,
                'a_radius': 161,
                'electron_config': '[Rn]5f26d17s2', 
                'electronegativity': 1.5,
                'electron_affinity': None,
                'ionization_energies': 568,
                'class': 'actinide',
                'oxidation_nums': [4, 5],
                'melting_temp': 1845, 
                'boiling_temp': 4029,
                'd': 15400,
                'yr': 1917 
            },
            'U': {
                'name': 'Uranium',
                'symbol': 'U',
                'a_num': 92,
                'a_mass': 238,
                'a_radius': None,
                'electron_config': '[Rn]5f36d17s2', 
                'electronegativity': 1.38,
                'electron_affinity': None,
                'ionization_energies': 597,
                'class': 'actinide',
                'oxidation_nums': [3, 4, 5, 6],
                'melting_temp': 1408, 
                'boiling_temp': 4404,
                'd': 19000,
                'yr': 1789 
            },
            'Np': {
                'name': 'Neptunium',
                'symbol': 'Np',
                'a_num': 93,
                'a_mass': 237,
                'a_radius': None,
                'electron_config': '[Rn]5f46d17s2', 
                'electronegativity': 1.36,
                'electron_affinity': None,
                'ionization_energies': 634,
                'class': 'actinide',
                'oxidation_nums': [3, 4, 5, 6, 7],
                'melting_temp': 913, 
                'boiling_temp': 4175,
                'd': 20400,
                'yr': 1940 
            },
            'Pu': {
                'name': 'Plutonium',
                'symbol': 'Pu',
                'a_num': 94,
                'a_mass': 244,
                'a_radius': None,
                'electron_config': '[Rn]5f67s2', 
                'electronegativity': 1.28,
                'electron_affinity': None,
                'ionization_energies': 637,
                'class': 'actinide',
                'oxidation_nums': [3, 4, 5, 6],
                'melting_temp': 914, 
                'boiling_temp': 3501,
                'd': 19700,
                'yr': 1940 
            },
            'Am': {
                'name': 'Americium',
                'symbol': 'Am',
                'a_num': 95,
                'a_mass': 243,
                'a_radius': None,
                'electron_config': '[Rn]5f77s2', 
                'electronegativity': 1.3,
                'electron_affinity': None,
                'ionization_energies': 578,
                'class': 'actinide',
                'oxidation_nums': [3, 4],
                'melting_temp': 1449, 
                'boiling_temp': 2284,
                'd': 13700,
                'yr': 1944 
            },
            'Cm': {
                'name': 'Curium',
                'symbol': 'Cm',
                'a_num': 96,
                'a_mass': 247,
                'a_radius': None,
                'electron_config': '[Rn]5f76d17s2', 
                'electronegativity': 1.3,
                'electron_affinity': None,
                'ionization_energies': 608,
                'class': 'actinide',
                'oxidation_nums': [3],
                'melting_temp': 1618, 
                'boiling_temp': None,
                'd': 13500,
                'yr': 1944 
            },
            'Bk': {
                'name': 'Berkelium',
                'symbol': 'Bk',
                'a_num': 97,
                'a_mass': 247,
                'a_radius': None,
                'electron_config': '[Rn]5f87s2', 
                'electronegativity': 1.3,
                'electron_affinity': None,
                'ionization_energies': 605,
                'class': 'actinide',
                'oxidation_nums': [3, 4],
                'melting_temp': 1323, 
                'boiling_temp': None,
                'd': 14800,
                'yr': 1949 
            },
            'Cf': {
                'name': 'Californium',
                'symbol': 'Cf',
                'a_num': 98,
                'a_mass': 251,
                'a_radius': None,
                'electron_config': '[Rn]5f107s2', 
                'electronegativity': 1.3,
                'electron_affinity': None,
                'ionization_energies': 608,
                'class': 'actinide',
                'oxidation_nums': [3],
                'melting_temp': 1333, 
                'boiling_temp': None,
                'd': None,
                'yr': 1950 
            },
            'Es': {
                'name': 'Einsteinium',
                'symbol': 'Es',
                'a_num': 99,
                'a_mass': 252,
                'a_radius': None,
                'electron_config': '[Rn]5f117s2', 
                'electronegativity': 1.3,
                'electron_affinity': None,
                'ionization_energies': 619,
                'class': 'actinide',
                'oxidation_nums': [3],
                'melting_temp': 1133, 
                'boiling_temp': None,
                'd': 15100,
                'yr': 1952 
            },
            'Fm': {
                'name': 'Fermium',
                'symbol': 'Fm',
                'a_num': 100,
                'a_mass': 257,
                'a_radius': None,
                'electron_config': '[Rn]5f127s2', 
                'electronegativity': 1.3,
                'electron_affinity': None,
                'ionization_energies': 627,
                'class': 'actinide',
                'oxidation_nums': [3],
                'melting_temp': 1800, 
                'boiling_temp': None,
                'd': None,
                'yr': 1953
            },
            'Md': {
                'name': 'Mendelevium',
                'symbol': 'Md',
                'a_num': 101,
                'a_mass': 258,
                'a_radius': None,
                'electron_config': '[Rn]5f137s2', 
                'electronegativity': 1.3,
                'electron_affinity': None,
                'ionization_energies': 637,
                'class': 'actinide',
                'oxidation_nums': [2, 3],
                'melting_temp': 1100, 
                'boiling_temp': None,
                'd': None,
                'yr': 1955 
            },
            'No': {
                'name': 'Nobelium',
                'symbol': 'No',
                'a_num': 102,
                'a_mass': 259,
                'a_radius': None,
                'electron_config': '[Rn]5f147s2', 
                'electronegativity': 1.3,
                'electron_affinity': None,
                'ionization_energies': 642,
                'class': 'actinide',
                'oxidation_nums': [2, 3],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 1958 
            },
            'Lr': {
                'name': 'Lawrencium',
                'symbol': 'Lr',
                'a_num': 103,
                'a_mass': 262,
                'a_radius': None,
                'electron_config': '[Rn]5f146d17s2', 
                'electronegativity': 1.3,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': 'actinide',
                'oxidation_nums': [3],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 1961 
            },
            'Rf': {
                'name': 'Rutherfordium',
                'symbol': 'Rf',
                'a_num': 104,
                'a_mass': 261,
                'a_radius': None,
                'electron_config': '[Rn]5f146d27s2', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': 'd block transition metal',
                'oxidation_nums': [4],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 1964
            },
            'Db': {
                'name': 'Dubnium',
                'symbol': 'Db',
                'a_num': 105,
                'a_mass': 262,
                'a_radius': None,
                'electron_config': '[Rn]5f146d37s2', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': 'd block transition metal',
                'oxidation_nums': [],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 1968 
            },
            'Sg': {
                'name': 'Seaborgium',
                'symbol': 'Sg',
                'a_num': 106,
                'a_mass': 266,
                'a_radius': None,
                'electron_config': '[Rn]5f146d47s2', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': 'd block transition metal',
                'oxidation_nums': [],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 1974 
            },
            'Bh': {
                'name': 'Bohrium',
                'symbol': 'Bh',
                'a_num': 107,
                'a_mass': 264,
                'a_radius': None,
                'electron_config': '[Rn]5f146d57s2', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': 'd block transition metal',
                'oxidation_nums': [],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 1976 
            },
            'Hs': {
                'name': 'Hassium',
                'symbol': 'Hs',
                'a_num': 108,
                'a_mass': 265,
                'a_radius': None,
                'electron_config': '[Rn]5f146d67s2', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': 'd block transition metal',
                'oxidation_nums': [],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 1984 
            },
            'Mt': {
                'name': 'Meitnerium',
                'symbol': 'Mt',
                'a_num': 109,
                'a_mass': 266,
                'a_radius': None,
                'electron_config': '[Rn]5f146d77s2', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': 840,
                'class': 'd block transition metal',
                'oxidation_nums': [],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 1982 
            },
            'Ds': {
                'name': 'Darmstadtium',
                'symbol': 'Ds',
                'a_num': 110,
                'a_mass': 271,
                'a_radius': None,
                'electron_config': '[Rn]5f146d87s2', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': 'd block transition metal',
                'oxidation_nums': [],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 1994 
            },
            'Rg': {
                'name': 'Roentgenium',
                'symbol': 'Rg',
                'a_num': 111,
                'a_mass': 272,
                'a_radius': None,
                'electron_config': '[Rn]5f146d97s2', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': 'd block transition metal',
                'oxidation_nums': [],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 1994 
            },
            'Cn': {
                'name': 'Copernicium',
                'symbol': 'Cn',
                'a_num': 112,
                'a_mass': 285,
                'a_radius': None,
                'electron_config': '[Rn]5f146d107s2', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': 'd block transition metal',
                'oxidation_nums': [],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 1996 
            },
            'Nh': {
                'name': 'Nihonium',
                'symbol': 'Nh',
                'a_num': 113,
                'a_mass': 284,
                'a_radius': None,
                'electron_config': '[Rn]5f146d107s27p1', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': '/',
                'oxidation_nums': [],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 2004
            },
            'Fl': {
                'name': 'Flerovium',
                'symbol': 'Fl',
                'a_num': 114,
                'a_mass': 289,
                'a_radius': None,
                'electron_config': '[Rn]5f146d107s27p2', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': '/',
                'oxidation_nums': [],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 1999 
            },
            'Mc': {
                'name': 'Moscovium',
                'symbol': 'Mc',
                'a_num': 115,
                'a_mass': 288,
                'a_radius': None,
                'electron_config': '[Rn]5f146d107s27p3', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': '/',
                'oxidation_nums': [],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 2003 
            },
            'Lv': {
                'name': 'Livermorium',
                'symbol': 'Lv',
                'a_num': 116,
                'a_mass': 293,
                'a_radius': None,
                'electron_config': '[Rn]5f146d107s27p4', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': '/',
                'oxidation_nums': [],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 2000 
            },
            'Ts': {
                'name': 'Tennessine',
                'symbol': 'Ts',
                'a_num': 117,
                'a_mass': 294,
                'a_radius': None,
                'electron_config': '[Rn]5f146d107s27p5', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': '/',
                'oxidation_nums': [],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 2010 
            },
            'Og': {
                'name': 'Oganesson',
                'symbol': 'Og',
                'a_num': 118,
                'a_mass': 294,
                'a_radius': None,
                'electron_config': '[Rn]5f146d107s27p6', 
                'electronegativity': None,
                'electron_affinity': None,
                'ionization_energies': None,
                'class': '/',
                'oxidation_nums': [],
                'melting_temp': None, 
                'boiling_temp': None,
                'd': None,
                'yr': 2006 
            }
        }
                
        self.table = {}
        for key, value in data.items():
            self.table[key] = Element(
                value["name"],
                value["symbol"],
                value["a_num"],
                value["a_mass"],
                value["a_radius"],
                value["electron_config"],
                value["electronegativity"],
                value["electron_affinity"],
                value["ionization_energies"],
                value["class"],
                value["oxidation_nums"],
                value["melting_temp"],
                value["boiling_temp"],
                value["d"],
                value["yr"]
            )
            
    def elem(self, ind):
        return self.table[ind]
    
table = Table()

def parse_formula(formula):
    pattern = r'([A-Z][a-z]?)(\d*)'
    counts = {}
    for element, count in re.findall(pattern, formula):
        counts[element] = counts.get(element, 0) + (int(count) if count else 1)
    return counts

def format(elem):
    match = re.match(r'\{(.*?)\}(.*)', elem)
    if not match:
        raise ValueError("Invalid format")    
    key, formula = match.groups()
    return {key: parse_formula(formula)}

def calc_mass(elem):
    mass = 0
    for molec in elem.keys():
        for i in range(int(molec)):
            for atom in elem[molec].keys():
                if atom not in table.table:
                    raise ValueError(f"Element {atom} not found in the periodic table")
                mass += table.elem(atom).a_mass * elem[molec][atom]
    
    return mass